@@ -88,7 +88,7 @@ int tpmUnsealFile( char* fname, unsigned char** tss_data, int* tss_size,
 	int res_size = 0;
 
 	BIO *bdata = NULL, *b64 = NULL, *bmem = NULL;
-	int bioRc;
+	int bioRc = 0;
 
 	if ( tss_data == NULL || tss_size == NULL ) {
 		rc = TPMSEAL_STD_ERROR;
@@ -185,6 +185,11 @@ int tpmUnsealFile( char* fname, unsigned char** tss_data, int* tss_size,
 	BIO_free(b64);
 	b64 = NULL;
 	bioRc = BIO_reset(bmem);
+	if (bioRc != 1) {
+		tpm_errno = EIO;
+		rc = TPMSEAL_STD_ERROR;
+		goto out;
+	}
 
 	/* Check for EVP Key Type Header */
 	BIO_gets(bdata, data, sizeof(data));
@@ -252,6 +257,11 @@ int tpmUnsealFile( char* fname, unsigned char** tss_data, int* tss_size,
 	BIO_free(b64);
 	b64 = NULL;
 	bioRc = BIO_reset(bmem);
+	if (bioRc != 1) {
+		tpm_errno = EIO;
+		rc = TPMSEAL_STD_ERROR;
+		goto out;
+	}
 
 	/* Read the base64 encrypted data into the memory BIO */
 	while ((rcLen = BIO_gets(bdata, data, sizeof(data))) > 0) {
@@ -419,7 +429,13 @@ int tpmUnsealFile( char* fname, unsigned char** tss_data, int* tss_size,
 	bmem = BIO_pop(b64);
 	BIO_free(b64);
 	b64 = NULL;
+	/* a BIO_reset failure shouldn't have an affect at this point */
 	bioRc = BIO_reset(bmem);
+	if (bioRc != 1) {
+		tpm_errno = EIO;
+		rc = TPMSEAL_STD_ERROR;
+		goto out;
+	}
 
 tss_out:
 	Tspi_Context_Close(hContext);
@@ -437,6 +453,11 @@ out:
 		BIO_free(bmem);
 	}
 
+	if (bioRc != 1) {
+		tpm_errno = EIO;
+		rc = TPMSEAL_STD_ERROR;
+	}
+
 	if ( evpKeyData )
 		free(evpKeyData);
 	if ( tssKeyData )
